==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/apps/app_service/app_service_proxy_factory.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_APPS_APP_SERVICE_APP_SERVICE_PROXY_FACTORY_H_
#define CHROME_BROWSER_APPS_APP_SERVICE_APP_SERVICE_PROXY_FACTORY_H_

#include "base/macros.h"
#include "base/memory/singleton.h"
#include "components/keyed_service/content/browser_context_keyed_service_factory.h"

class Profile;

namespace apps {

class AppServiceProxy;

// Singleton that owns all AppServiceProxy's and associates them with Profile.
class AppServiceProxyFactory : public BrowserContextKeyedServiceFactory {
 public:
  static bool IsAppServiceAvailableForProfile(Profile* profile);

  static AppServiceProxy* GetForProfile(Profile* profile);

  // Explicitly avoids DumpWithoutCrashing() when App Service is not available
  // for a Profile. Avoid using this unless you have spoken with App Service
  // OWNERs.
  static AppServiceProxy* GetForProfileRedirectInIncognito(Profile* profile);

  static AppServiceProxyFactory* GetInstance();

 private:
  friend struct base::DefaultSingletonTraits<AppServiceProxyFactory>;

  AppServiceProxyFactory();
  ~AppServiceProxyFactory() override;

  // BrowserContextKeyedServiceFactory overrides.
  KeyedService* BuildServiceInstanceFor(
      content::BrowserContext* context) const override;
  content::BrowserContext* GetBrowserContextToUse(
      content::BrowserContext* context) const override;
  bool ServiceIsCreatedWithBrowserContext() const override;

  DISALLOW_COPY_AND_ASSIGN(AppServiceProxyFactory);
};

}  // namespace apps

#endif  // CHROME_BROWSER_APPS_APP_SERVICE_APP_SERVICE_PROXY_FACTORY_H_

==> chromium_90.0.4430.212.orig.tar.xz: chromium-90.0.4430.212/chrome/browser/apps/app_service/app_service_proxy_factory.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_APPS_APP_SERVICE_APP_SERVICE_PROXY_FACTORY_H_
#define CHROME_BROWSER_APPS_APP_SERVICE_APP_SERVICE_PROXY_FACTORY_H_

#include "base/memory/singleton.h"
#include "components/keyed_service/content/browser_context_keyed_service_factory.h"

class Profile;

namespace apps {

class AppServiceProxy;

// Singleton that owns all AppServiceProxy's and associates them with Profile.
class AppServiceProxyFactory : public BrowserContextKeyedServiceFactory {
 public:
  static bool IsAppServiceAvailableForProfile(Profile* profile);

  static AppServiceProxy* GetForProfile(Profile* profile);

  // Explicitly avoids DumpWithoutCrashing() when App Service is not available
  // for a Profile. Avoid using this unless you have spoken with App Service
  // OWNERs.
  static AppServiceProxy* GetForProfileRedirectInIncognito(Profile* profile);

  static AppServiceProxyFactory* GetInstance();

  AppServiceProxyFactory(const AppServiceProxyFactory&) = delete;
  AppServiceProxyFactory& operator=(const AppServiceProxyFactory&) = delete;

 private:
  friend struct base::DefaultSingletonTraits<AppServiceProxyFactory>;

  AppServiceProxyFactory();
  ~AppServiceProxyFactory() override;

  // BrowserContextKeyedServiceFactory overrides.
  KeyedService* BuildServiceInstanceFor(
      content::BrowserContext* context) const override;
  content::BrowserContext* GetBrowserContextToUse(
      content::BrowserContext* context) const override;
  bool ServiceIsCreatedWithBrowserContext() const override;
};

}  // namespace apps

#endif  // CHROME_BROWSER_APPS_APP_SERVICE_APP_SERVICE_PROXY_FACTORY_H_
